# Sample code for controlling an ASCOM dome

import sys
from win32com.client import Dispatch

# Each ASCOM driver is identified by a string.
# This will show a window that allows you to select from a list
# of registered ASCOM dome drivers. A string will be returned.
# Once you know the string for your dome, you can bypass this step
# and just use that string directly

dome = None

def main():
    global dome

    chooser = Dispatch("DriverHelper.Chooser")
    chooser.DeviceType = "Dome"
    defaultSelectedDriver = "DomeSim.Dome" # Highlight the Simulator driver by default
    driverName = chooser.Choose(defaultSelectedDriver)

    if driverName == "":
        print "User clicked the Cancel button"
        sys.exit(1)

    print "Loading driver '%s'" % driverName

    dome = Dispatch(driverName)

    print "Connecting to dome"
    dome.Connected = True

    while True:
        showStatus()
        getInput()


def showStatus():
    rotationStatus = "Stopped"
    if dome.Slewing:
        rotationStatus = "Slewing"

    shutterStatusInt = dome.ShutterStatus
    shutterStatusToText = {
            0: "Open",
            1: "Closed",
            2: "Opening",
            3: "Closing",
            4: "Error"
        }

    shutterStatus = shutterStatusToText.get(shutterStatusInt, "Unknown")

    print "Current azimuth: %.2f" % dome.Azimuth
    print "Rotation status: %s" % rotationStatus
    print "Shutter status: %s" % shutterStatus

    print
    print "Enter a command:"
    print " h: Find home"
    print " o: Open shutter"
    print " c: Close shutter"
    print " s: Stop"
    print " g (azm): Go to specified azimuth"
    print " x: Exit"

def getInput():
    command = raw_input()
    command = command.strip().lower()

    if command == "x":
        sys.exit(0)
    elif command == "h":
        dome.FindHome()
    elif command == "o":
        dome.OpenShutter()
    elif command == "c":
        dome.CloseShutter()
    elif command == "s":
        dome.AbortSlew()
    elif command.startswith("g"):
        args = command.split(" ")
        try:
            azimuth = float(args[1])
        except:
            print
            print "INVALID INPUT. Sample usage: g 95.1"
            print
            return
        dome.SlewToAzimuth(azimuth)


if __name__ == "__main__":
    main()
